@@ -2,6 +2,19 @@ import unittest
 from ddt import ddt, data, file_data, unpack
 from test.mycode import larger_than_two, has_three_elements, is_a_greeting
 
+try:
+    import yaml
+except ImportError:  # pragma: no cover
+    have_yaml_support = False
+else:
+    have_yaml_support = True
+    del yaml
+
+# A good-looking decorator
+needs_yaml = unittest.skipUnless(
+    have_yaml_support, "Need YAML to run this test"
+)
+
 
 class Mylist(list):
     pass
@@ -32,17 +45,34 @@ class FooTestCase(unittest.TestCase):
         self.assertGreater(a, b)
 
     @file_data("test_data_dict_dict.json")
-    def test_file_data_dict_dict(self, start, end, value):
+    def test_file_data_json_dict_dict(self, start, end, value):
         self.assertLess(start, end)
         self.assertLess(value, end)
         self.assertGreater(value, start)
 
     @file_data('test_data_dict.json')
-    def test_file_data_dict(self, value):
+    def test_file_data_json_dict(self, value):
         self.assertTrue(has_three_elements(value))
 
     @file_data('test_data_list.json')
-    def test_file_data_list(self, value):
+    def test_file_data_json_list(self, value):
+        self.assertTrue(is_a_greeting(value))
+
+    @needs_yaml
+    @file_data("test_data_dict_dict.yaml")
+    def test_file_data_yaml_dict_dict(self, start, end, value):
+        self.assertLess(start, end)
+        self.assertLess(value, end)
+        self.assertGreater(value, start)
+
+    @needs_yaml
+    @file_data('test_data_dict.yaml')
+    def test_file_data_yaml_dict(self, value):
+        self.assertTrue(has_three_elements(value))
+
+    @needs_yaml
+    @file_data('test_data_list.yaml')
+    def test_file_data_yaml_list(self, value):
         self.assertTrue(is_a_greeting(value))
 
     @data((3, 2), (4, 3), (5, 3))
